==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QSignalBlocker_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qobject.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSignalBlocker(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSignalBlocker")
    QSignalBlocker *_ptr = reinterpret_cast<QSignalBlocker *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QSignalBlocker(QObject*)
void __qt_construct_QSignalBlocker_QObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSignalBlocker(QObject*)")
    jobject o0 = __java_arguments[0].l;
    QObject* __qt_o0 = qtjambi_cast<QObject* >(__jni_env, o0);
    QSignalBlocker *__qt_this = new(__qtjambi_ptr) QSignalBlocker(__qt_o0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QSignalBlocker::QSignalBlocker(QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_initialize_1native__Lio_qt_core_QSignalBlocker_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject o0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSignalBlocker::QSignalBlocker(QObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = o0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSignalBlocker_QObject_ptr, sizeof(QSignalBlocker), typeid(QSignalBlocker), false, &deleter_QSignalBlocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSignalBlocker
void __qt_destruct_QSignalBlocker(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSignalBlocker")
    reinterpret_cast<QSignalBlocker*>(ptr)->~QSignalBlocker();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSignalBlocker::reblock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_reblock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSignalBlocker *__qt_this = QtJambiAPI::objectFromNativeId<QSignalBlocker>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSignalBlocker::reblock()", __qt_this)
        __qt_this->reblock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSignalBlocker::unblock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_unblock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSignalBlocker *__qt_this = QtJambiAPI::objectFromNativeId<QSignalBlocker>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSignalBlocker::unblock()", __qt_this)
        __qt_this->unblock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSignalBlocker(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSignalBlocker>("QSignalBlocker", "io/qt/core/QSignalBlocker");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSignalBlocker, {
        ConstructorInfo(&__qt_construct_QSignalBlocker_QObject_ptr, "Lio/qt/core/QObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSignalBlocker);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QSignalBlocker_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qobject.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSignalBlocker(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSignalBlocker")
    QSignalBlocker *_ptr = reinterpret_cast<QSignalBlocker *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QSignalBlocker(QObject*)
void __qt_construct_QSignalBlocker_QObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSignalBlocker(QObject*)")
    jobject o0 = __java_arguments[0].l;
    QObject* __qt_o0 = qtjambi_cast<QObject*>(__jni_env, o0);
    QSignalBlocker *__qt_this = new(__qtjambi_ptr) QSignalBlocker(__qt_o0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QSignalBlocker::QSignalBlocker(QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_initialize_1native__Lio_qt_core_QSignalBlocker_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject o0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSignalBlocker::QSignalBlocker(QObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = o0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSignalBlocker_QObject_ptr, sizeof(QSignalBlocker), typeid(QSignalBlocker), 0, false, &deleter_QSignalBlocker, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSignalBlocker
void __qt_destruct_QSignalBlocker(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSignalBlocker")
    reinterpret_cast<QSignalBlocker*>(ptr)->~QSignalBlocker();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSignalBlocker::dismiss()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_dismiss_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSignalBlocker *__qt_this = QtJambiAPI::objectFromNativeId<QSignalBlocker>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSignalBlocker::dismiss()", __this_nativeId)
        __qt_this->dismiss();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSignalBlocker::reblock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_reblock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSignalBlocker *__qt_this = QtJambiAPI::objectFromNativeId<QSignalBlocker>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSignalBlocker::reblock()", __this_nativeId)
        __qt_this->reblock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSignalBlocker::unblock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QSignalBlocker_unblock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSignalBlocker *__qt_this = QtJambiAPI::objectFromNativeId<QSignalBlocker>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSignalBlocker::unblock()", __this_nativeId)
        __qt_this->unblock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSignalBlocker(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSignalBlocker>("QSignalBlocker", "io/qt/core/QSignalBlocker");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSignalBlocker, {
        ConstructorInfo(&__qt_construct_QSignalBlocker_QObject_ptr, "Lio/qt/core/QObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSignalBlocker);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
